@@ -35,8 +35,8 @@ import edbob
 from edbob.pyramid.forms import PrettyDateTimeFieldRenderer
 from ...forms import EnumFieldRenderer
 from ...grids.search import BooleanSearchFilter
-from edbob.pyramid.progress import SessionProgress
 from .. import SearchableAlchemyGridView, CrudView, View
+from ...progress import SessionProgress
 
 from rattail import enum
 from rattail import batches
