@@ -35,7 +35,6 @@ from pyramid.httpexceptions import HTTPFound
 from pyramid.renderers import render_to_response
 
 import edbob
-from edbob.pyramid.progress import SessionProgress
 from . import SearchableAlchemyGridView
 
 import rattail.labels
@@ -52,6 +51,7 @@ from rattail.db.api import get_product_by_upc
 from ..db import Session
 from ..forms import GPCFieldRenderer, BrandFieldRenderer, PriceFieldRenderer
 from . import CrudView
+from ..progress import SessionProgress
 
 
 class ProductsGrid(SearchableAlchemyGridView):
